-- $Id: Polynomials.hs,v 1.3 2013/08/18 16:42:00 leavens Exp leavens $
module Polynomials where

-- Polynomials are represented by finite lists of coefficients,
-- with the zeroth coefficient being the constant (representing x^0)
-- and the nth (zero-based) coefficient multiplied by x^n.
-- For example, the polynomial 0.0 is represented by both [] and [0.0].
-- Also 4.1x + 5.0 is represented by [5.0, 4.1] both and [5.0, 4.1, 0.0].
-- 4.1x^2 + 2.2x + 5.7 is represented by [5.7, 2.2, 4.1].
type Polynomial = [Double]
evaluate :: Polynomial -> Double -> Double
scaleBy :: Double -> Polynomial -> Polynomial
add :: Polynomial -> Polynomial -> Polynomial
sub :: Polynomial -> Polynomial -> Polynomial

-- evaluate p x is the value of the polynomial p where the unknown is x.
-- So evaluate [5.7, 2.2, 4.1] 10.0 is 5.7 + 2.2*10.0 + 4.1*10.0^2
evaluate p x = eval p x 0.0 0
    where eval :: Polynomial -> Double -> Double -> Int -> Double
          eval [] x acc expon = acc
          eval (c:cs) x acc expon = eval cs x (acc + c*(x^expon)) (expon+1)

-- scaleBy returns the Polynomial with each coefficient multiplied by the Double
-- WRITE YOUR CODE HERE

-- add returns a Polynomial that is the sum of the two arguments.
-- WRITE YOUR CODE HERE

-- sub returns the second argument Polynomial subtracted from the first
-- WRITE YOUR CODE HERE
